SentryHive top-level property
Use SentryHive constant instead of Hive to get automatic performance
monitoring.
Implementation
@experimental
// ignore: non_constant_identifier_names
SentryHiveInterface SentryHive = SentryHiveImpl(Hive);
Use SentryHive constant instead of Hive to get automatic performance
monitoring.
@experimental
// ignore: non_constant_identifier_names
SentryHiveInterface SentryHive = SentryHiveImpl(Hive);